@@ -1,5 +1,3 @@
-context("Rank variables")
-
 cas <- smart_read("cas500.csv")
 # cas <- smart_read("tests/testthat/cas500.csv")
 
@@ -9,9 +7,10 @@ test_that("Ranking works for iid data", {
         d$rightfoot.rank,
         dplyr::min_rank(d$rightfoot)
     )
-    expect_equivalent(
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
 
@@ -21,9 +20,10 @@ svy <- svydesign(~dnum+snum, weights = ~pw, fpc = ~fpc1+fpc2, data = apiclus2)
 
 test_that("Ranking works for surveys", {
     d <- rankVars(svy, c("api00", "enroll"))
-    expect_is(d, "survey.design2")
-    expect_equivalent(
+    expect_s3_class(d, "survey.design2")
+    expect_equal(
         eval(parse(text = attr(d, "code"))),
-        d
+        d,
+        ignore_attr = TRUE
     )
 })
