@@ -21,6 +21,12 @@ test_that("Cody tidying does not break code", {
     expect_equal(d1, d2)
 })
 
+test_that("Code writing can remove library calls", {
+    x <- readLines("messy_gapminder.txt")
+    z <- tidy_all_code(x, incl_library = FALSE)
+    expect_false(any(grepl("tibble::", z)))
+})
+
 test_that("Cody tidying does not break code 2", {
     x <- readLines("messy_census.txt")
     z <- tidy_all_code(x)
@@ -55,3 +61,8 @@ test_that("print_code works OK", {
         "No code attached to this object."
     )
 })
+
+test_that("tidying from file works OK", {
+    x <- tidy_all_code("messy_gapminder.txt")
+    expect_true(length(x) > 0)
+})
